@@ -15,7 +15,7 @@ Features:
   codes
 - Synchronous I/O (control, bulk, interrupt)
 - Asynchronous I/O (control, bulk, interrupt, isochronous)
-  Note: Isochronous support is experimental.
+  Note: Isochronous support is not well tested.
   See USBPoller, USBTransfer and USBTransferHelper.
 """
 
@@ -297,8 +297,8 @@ class USBTransfer(object):
                 '%i bytes available' % (sum(iso_transfer_length_list),
                     buffer_length))
         transfer_p = self.__transfer
-        max_iso_packet_size = self.__handle.getDevice().getMaxISOPacketSize(
-            endpoint)
+        #max_iso_packet_size = self.__handle.getDevice().getMaxISOPacketSize(
+        #    endpoint)
         self.__initialized = False
         libusb1.libusb_fill_iso_transfer(transfer_p, self.__handle,
             endpoint, string_buffer, buffer_length, configured_iso_packets,
@@ -308,9 +308,9 @@ class USBTransfer(object):
             if length <= 0:
                 raise ValueError('Negative/null length transfers are not '
                     'possible.')
-            if length > max_iso_packet_size:
-                raise ValueError('Packet too big (%i) for this endpoint: %i '
-                    'bytes max')
+            #if length > max_iso_packet_size:
+            #    raise ValueError('Packet too big (%i) for this endpoint: %i '
+            #        'bytes max')
             iso_packet_desc.length = length
         self.__callback = callback
         self.__initialized = True
@@ -360,6 +360,7 @@ class USBTransfer(object):
         Get individual ISO transfer's buffer.
         Returns a list with one item per ISO transfer, with their
         individually-configured sizes.
+        Returned list is consistent with getISOSetupList return value.
         Should not be called on a submitted transfer.
         """
         transfer_p = self.__transfer
@@ -378,6 +379,7 @@ class USBTransfer(object):
         - actual_length
         - status
         (see libusb1's API documentation for their signification)
+        Returned list is consistent with getISOBufferList return value.
         Should not be called on a submitted transfer (except for 'length'
         values).
         """
@@ -1443,7 +1445,7 @@ class LibUSBContext(object):
         Handle any pending event.
         If tv is 0, will return immediately after handling already-pending
         events.
-        Othewire, defines the maximum amount of time to wait for events, in
+        Otherwise, defines the maximum amount of time to wait for events, in
         seconds.
         """
         if tv is None:
